# coding: utf-8

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class Flow(str, Enum):
    """
    Which money flow a connected account belongs to — routes the fork.
    """

    """
    allowed enum values
    """
    ACCESS = 'access'
    PORTAL = 'portal'

    @classmethod
    def from_json(cls, json_str: str) -> Flow:
        """Create an instance of Flow from a JSON string"""
        return Flow(json.loads(json_str))


