# coding: utf-8

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from marketplace_server_connector.models.wrapped_response_drain_out import WrappedResponseDrainOut  # noqa: E501

class TestWrappedResponseDrainOut(unittest.TestCase):
    """WrappedResponseDrainOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponseDrainOut:
        """Test WrappedResponseDrainOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponseDrainOut`
        """
        model = WrappedResponseDrainOut()  # noqa: E501
        if include_optional:
            return WrappedResponseDrainOut(
                done = True,
                result = marketplace_server_connector.models.drain_out.DrainOut(
                    processed = 56, 
                    relayed = 56, )
            )
        else:
            return WrappedResponseDrainOut(
                result = marketplace_server_connector.models.drain_out.DrainOut(
                    processed = 56, 
                    relayed = 56, ),
        )
        """

    def testWrappedResponseDrainOut(self):
        """Test WrappedResponseDrainOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
