# coding: utf-8

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from marketplace_server_connector.models.wrapped_response_list_account_out import WrappedResponseListAccountOut  # noqa: E501

class TestWrappedResponseListAccountOut(unittest.TestCase):
    """WrappedResponseListAccountOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponseListAccountOut:
        """Test WrappedResponseListAccountOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponseListAccountOut`
        """
        model = WrappedResponseListAccountOut()  # noqa: E501
        if include_optional:
            return WrappedResponseListAccountOut(
                done = True,
                result = [
                    marketplace_server_connector.models.account_out.AccountOut(
                        id = 56, 
                        provider = 'digistore', 
                        flow = 'access', 
                        is_active = True, 
                        credential_keys = [
                            ''
                            ], 
                        created_at = 56, 
                        updated_at = 56, )
                    ]
            )
        else:
            return WrappedResponseListAccountOut(
                result = [
                    marketplace_server_connector.models.account_out.AccountOut(
                        id = 56, 
                        provider = 'digistore', 
                        flow = 'access', 
                        is_active = True, 
                        credential_keys = [
                            ''
                            ], 
                        created_at = 56, 
                        updated_at = 56, )
                    ],
        )
        """

    def testWrappedResponseListAccountOut(self):
        """Test WrappedResponseListAccountOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
