# coding: utf-8

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr
from marketplace_server_connector.models.provider import Provider

class AccountSyncOut(BaseModel):
    """
    One account's sync outcome (POST /products/sync runs one per active account).  # noqa: E501
    """
    account_id: StrictInt = Field(...)
    provider: Provider = Field(...)
    supported: StrictBool = Field(...)
    created: Optional[StrictInt] = 0
    updated: Optional[StrictInt] = 0
    archived: Optional[StrictInt] = 0
    error: Optional[StrictStr] = None
    __properties = ["account_id", "provider", "supported", "created", "updated", "archived", "error"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AccountSyncOut:
        """Create an instance of AccountSyncOut from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if error (nullable) is None
        # and __fields_set__ contains the field
        if self.error is None and "error" in self.__fields_set__:
            _dict['error'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AccountSyncOut:
        """Create an instance of AccountSyncOut from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AccountSyncOut.parse_obj(obj)

        _obj = AccountSyncOut.parse_obj({
            "account_id": obj.get("account_id"),
            "provider": obj.get("provider"),
            "supported": obj.get("supported"),
            "created": obj.get("created") if obj.get("created") is not None else 0,
            "updated": obj.get("updated") if obj.get("updated") is not None else 0,
            "archived": obj.get("archived") if obj.get("archived") is not None else 0,
            "error": obj.get("error")
        })
        return _obj


