# coding: utf-8

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from marketplace_server_connector.api.admin_api import AdminApi  # noqa: E501


class TestAdminApi(unittest.IsolatedAsyncioTestCase):
    """AdminApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = AdminApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_drain_v1_admin_drain_post(self) -> None:
        """Test case for drain_v1_admin_drain_post

        Process queued IPNs then relay pending outbox rows  # noqa: E501
        """
        pass

    async def test_health_health_get(self) -> None:
        """Test case for health_health_get

        Health check  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
