# coding: utf-8

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from marketplace_server_connector.models.wrapped_response_list_account_sync_out import WrappedResponseListAccountSyncOut  # noqa: E501

class TestWrappedResponseListAccountSyncOut(unittest.TestCase):
    """WrappedResponseListAccountSyncOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponseListAccountSyncOut:
        """Test WrappedResponseListAccountSyncOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponseListAccountSyncOut`
        """
        model = WrappedResponseListAccountSyncOut()  # noqa: E501
        if include_optional:
            return WrappedResponseListAccountSyncOut(
                done = True,
                result = [
                    marketplace_server_connector.models.account_sync_out.AccountSyncOut(
                        account_id = 56, 
                        provider = 'digistore', 
                        supported = True, 
                        created = 56, 
                        updated = 56, 
                        archived = 56, 
                        error = '', )
                    ]
            )
        else:
            return WrappedResponseListAccountSyncOut(
                result = [
                    marketplace_server_connector.models.account_sync_out.AccountSyncOut(
                        account_id = 56, 
                        provider = 'digistore', 
                        supported = True, 
                        created = 56, 
                        updated = 56, 
                        archived = 56, 
                        error = '', )
                    ],
        )
        """

    def testWrappedResponseListAccountSyncOut(self):
        """Test WrappedResponseListAccountSyncOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
