# coding: utf-8

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from marketplace_server_connector.models.flow import Flow  # noqa: E501

class TestFlow(unittest.TestCase):
    """Flow unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testFlow(self):
        """Test Flow"""
        # inst = Flow()

if __name__ == '__main__':
    unittest.main()
